@@ -1,18 +1,18 @@
-# flake8: NOQA E5
+# flake8: NOQA: E501
+import contextlib
 import inspect
+import pathlib
 import sys
-from os.path import dirname, relpath
-from pathlib import Path
 import typing as t
+from os.path import relpath
 
-import libtmux  # NOQA
-from libtmux import test  # NOQA
+import libtmux
 
 if t.TYPE_CHECKING:
     from sphinx.application import Sphinx
 
 # Get the project root dir, which is the parent dir of this
-cwd = Path(__file__).parent
+cwd = pathlib.Path(__file__).parent
 project_root = cwd.parent
 project_src = project_root / "src"
 
@@ -21,7 +21,7 @@ sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
 about: t.Dict[str, str] = {}
-with open(project_src / "libtmux" / "__about__.py") as fp:
+with (project_src / "libtmux" / "__about__.py").open() as fp:
     exec(fp.read(), about)
 
 extensions = [
@@ -122,16 +122,16 @@ rediraffe_branch = "master~1"
 # sphinxext.opengraph
 ogp_site_url = about["__docs__"]
 ogp_image = "_static/img/icons/icon-192x192.png"
-ogp_desscription_length = about["__description__"]
+ogp_description_length = about["__description__"]
 ogp_site_name = about["__title__"]
 
-htmlhelp_basename = "%sdoc" % about["__title__"]
+htmlhelp_basename = f"{about['__title__']}doc"
 
 latex_documents = [
     (
         "index",
-        "{}.tex".format(about["__package_name__"]),
-        "{} Documentation".format(about["__title__"]),
+        f"{about['__package_name__']}.tex",
+        f"{about['__title__']} Documentation",
         about["__author__"],
         "manual",
     )
@@ -141,7 +141,7 @@ man_pages = [
     (
         "index",
         about["__package_name__"],
-        "{} Documentation".format(about["__title__"]),
+        f"{about['__title__']} Documentation",
         about["__author__"],
         1,
     )
@@ -150,8 +150,8 @@ man_pages = [
 texinfo_documents = [
     (
         "index",
-        "{}".format(about["__package_name__"]),
-        "{} Documentation".format(about["__title__"]),
+        about["__package_name__"],
+        f"{about['__title__']} Documentation",
         about["__author__"],
         about["__package_name__"],
         about["__description__"],
@@ -165,9 +165,7 @@ intersphinx_mapping = {
 }
 
 
-def linkcode_resolve(
-    domain: str, info: t.Dict[str, str]
-) -> t.Union[None, str]:  # NOQA: C901
+def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     """
     Determine the URL corresponding to Python object
 
@@ -190,7 +188,7 @@ def linkcode_resolve(
     for part in fullname.split("."):
         try:
             obj = getattr(obj, part)
-        except Exception:
+        except Exception:  # noqa: PERF203
             return None
 
     # strip decorators, which would resolve to the source of the decorator
@@ -215,12 +213,9 @@ def linkcode_resolve(
     except Exception:
         lineno = None
 
-    if lineno:
-        linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1)
-    else:
-        linespec = ""
+    linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1) if lineno else ""
 
-    fn = relpath(fn, start=dirname(libtmux.__file__))
+    fn = relpath(fn, start=pathlib.Path(libtmux.__file__).parent)
 
     if "dev" in about["__version__"]:
         return "{}/blob/master/{}/{}/{}{}".format(
@@ -244,8 +239,9 @@ def linkcode_resolve(
 def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
     # Fix for sphinx-inline-tabs#18
     if app.builder.format == "html" and not exc:
-        tabs_js = Path(app.builder.outdir) / "_static" / "tabs.js"
-        tabs_js.unlink()
+        tabs_js = pathlib.Path(app.builder.outdir) / "_static" / "tabs.js"
+        with contextlib.suppress(FileNotFoundError):
+            tabs_js.unlink()  # When python 3.7 deprecated, use missing_ok=True
 
 
 def setup(app: "Sphinx") -> None:
