@@ -3,14 +3,11 @@
 import re
 import sys
 import typing as t
-from distutils.version import LooseVersion
-from typing import Optional
 
 import pytest
 
-from _pytest.monkeypatch import MonkeyPatch
-
 import libtmux
+from libtmux._compat import LooseVersion
 from libtmux.common import (
     TMUX_MAX_VERSION,
     TMUX_MIN_VERSION,
@@ -31,9 +28,9 @@ from libtmux.session import Session
 version_regex = re.compile(r"([0-9]\.[0-9])|(master)")
 
 
-def test_allows_master_version(monkeypatch: MonkeyPatch) -> None:
+def test_allows_master_version(monkeypatch: pytest.MonkeyPatch) -> None:
     class Hi:
-        stdout = ["tmux master"]
+        stdout: t.ClassVar = ["tmux master"]
         stderr = None
 
     def mock_tmux_cmd(*args: t.Any, **kwargs: t.Any) -> Hi:
@@ -49,11 +46,11 @@ def test_allows_master_version(monkeypatch: MonkeyPatch) -> None:
     ), "Is the latest supported version with -master appended"
 
 
-def test_allows_next_version(monkeypatch: MonkeyPatch) -> None:
+def test_allows_next_version(monkeypatch: pytest.MonkeyPatch) -> None:
     TMUX_NEXT_VERSION = str(float(TMUX_MAX_VERSION) + 0.1)
 
     class Hi:
-        stdout = [f"tmux next-{TMUX_NEXT_VERSION}"]
+        stdout: t.ClassVar = [f"tmux next-{TMUX_NEXT_VERSION}"]
         stderr = None
 
     def mock_tmux_cmd(*args: t.Any, **kwargs: t.Any) -> Hi:
@@ -64,12 +61,12 @@ def test_allows_next_version(monkeypatch: MonkeyPatch) -> None:
     assert has_minimum_version()
     assert has_gte_version(TMUX_MIN_VERSION)
     assert has_gt_version(TMUX_MAX_VERSION), "Greater than the max-supported version"
-    assert TMUX_NEXT_VERSION == get_version()
+    assert get_version() == TMUX_NEXT_VERSION
 
 
-def test_get_version_openbsd(monkeypatch: MonkeyPatch) -> None:
+def test_get_version_openbsd(monkeypatch: pytest.MonkeyPatch) -> None:
     class Hi:
-        stderr = ["tmux: unknown option -- V"]
+        stderr: t.ClassVar = ["tmux: unknown option -- V"]
 
     def mock_tmux_cmd(*args: t.Any, **kwargs: t.Any) -> Hi:
         return Hi()
@@ -84,9 +81,9 @@ def test_get_version_openbsd(monkeypatch: MonkeyPatch) -> None:
     ), "Is the latest supported version with -openbsd appended"
 
 
-def test_get_version_too_low(monkeypatch: MonkeyPatch) -> None:
+def test_get_version_too_low(monkeypatch: pytest.MonkeyPatch) -> None:
     class Hi:
-        stderr = ["tmux: unknown option -- V"]
+        stderr: t.ClassVar = ["tmux: unknown option -- V"]
 
     def mock_tmux_cmd(*args: t.Any, **kwargs: t.Any) -> Hi:
         return Hi()
@@ -97,7 +94,7 @@ def test_get_version_too_low(monkeypatch: MonkeyPatch) -> None:
     exc_info.match("is running tmux 1.3 or earlier")
 
 
-def test_ignores_letter_versions(monkeypatch: MonkeyPatch) -> None:
+def test_ignores_letter_versions(monkeypatch: pytest.MonkeyPatch) -> None:
     """Ignore letters such as 1.8b.
 
     See ticket https://github.com/tmux-python/tmuxp/issues/55.
@@ -115,12 +112,12 @@ def test_ignores_letter_versions(monkeypatch: MonkeyPatch) -> None:
     assert result
 
     # Should not throw
-    assert type(has_version("1.8")) is bool
-    assert type(has_version("1.8a")) is bool
-    assert type(has_version("1.9a")) is bool
+    assert isinstance(has_version("1.8"), bool)
+    assert isinstance(has_version("1.8a"), bool)
+    assert isinstance(has_version("1.9a"), bool)
 
 
-def test_error_version_less_1_7(monkeypatch: MonkeyPatch) -> None:
+def test_error_version_less_1_7(monkeypatch: pytest.MonkeyPatch) -> None:
     def mock_get_version() -> LooseVersion:
         return LooseVersion("1.7")
 
@@ -183,19 +180,25 @@ def test_tmux_cmd_unicode(session: Session) -> None:
     session.cmd("new-window", "-t", 3, "-n", "юникод", "-F", "Ελληνικά")
 
 
+class SessionCheckName(t.NamedTuple):
+    session_name: t.Optional[str]
+    raises: bool
+    exc_msg_regex: t.Optional[str]
+
+
 @pytest.mark.parametrize(
-    "session_name,raises,exc_msg_regex",
+    SessionCheckName._fields,
     [
-        ("", True, "may not be empty"),
-        (None, True, "may not be empty"),
-        ("my great session.", True, "may not contain periods"),
-        ("name: great session", True, "may not contain colons"),
-        ("new great session", False, None),
-        ("ajf8a3fa83fads,,,a", False, None),
+        SessionCheckName("", True, "empty"),
+        SessionCheckName(None, True, "empty"),
+        SessionCheckName("my great session.", True, "contains periods"),
+        SessionCheckName("name: great session", True, "contains colons"),
+        SessionCheckName("new great session", False, None),
+        SessionCheckName("ajf8a3fa83fads,,,a", False, None),
     ],
 )
 def test_session_check_name(
-    session_name: Optional[str], raises: bool, exc_msg_regex: Optional[str]
+    session_name: t.Optional[str], raises: bool, exc_msg_regex: t.Optional[str]
 ) -> None:
     if raises:
         with pytest.raises(BadSessionName) as exc_info:
