@@ -1,9 +1,10 @@
 """Test for libtmux Server object."""
 import logging
+import subprocess
 
 import pytest
 
-from libtmux.common import has_gte_version
+from libtmux.common import has_gte_version, has_version
 from libtmux.server import Server
 from libtmux.session import Session
 
@@ -71,12 +72,12 @@ def test_show_environment(server: Server) -> None:
 def test_getenv(server: Server, session: Session) -> None:
     """Set environment then Server.show_environment(key)."""
     server.set_environment("FOO", "BAR")
-    assert "BAR" == server.getenv("FOO")
+    assert server.getenv("FOO") == "BAR"
 
     server.set_environment("FOO", "DAR")
-    assert "DAR" == server.getenv("FOO")
+    assert server.getenv("FOO") == "DAR"
 
-    assert "DAR" == server.show_environment()["FOO"]
+    assert server.show_environment()["FOO"] == "DAR"
 
 
 def test_show_environment_not_set(server: Server) -> None:
@@ -127,6 +128,23 @@ def test_new_session_shell(server: Server) -> None:
         assert pane_start_command == cmd
 
 
+@pytest.mark.skipif(has_version("3.2"), reason="Wrong width returned with 3.2")
+def test_new_session_width_height(server: Server) -> None:
+    """Server.new_session creates and returns valid session running with
+    specified width /height"""
+    cmd = "/usr/bin/env PS1='$ ' sh"
+    mysession = server.new_session(
+        "test_new_session_width_height",
+        window_command=cmd,
+        x=32,
+        y=32,
+    )
+    window = mysession.windows[0]
+    pane = window.panes[0]
+    assert pane.display_message("#{window_width}", get_text=True)[0] == "32"
+    assert pane.display_message("#{window_height}", get_text=True)[0] == "32"
+
+
 def test_no_server_sessions() -> None:
     server = Server(socket_name="test_attached_session_no_server")
     assert server.sessions == []
@@ -149,7 +167,7 @@ def test_with_server_is_alive(server: Server) -> None:
 
 def test_no_server_raise_if_dead() -> None:
     dead_server = Server(socket_name="test_attached_session_no_server")
-    with pytest.raises(Exception):
+    with pytest.raises(subprocess.CalledProcessError):
         dead_server.raise_if_dead()
 
 
